Pin a post to its channel
pin_post.RdPin a post to the top of the channel it belongs to. This is the semantic endpoint for pinning; the same effect can be achieved via `update_post(post_id, is_pinned = TRUE)`.
pin_post.RdPin a post to the top of the channel it belongs to. This is the semantic endpoint for pinning; the same effect can be achieved via `update_post(post_id, is_pinned = TRUE)`.