Create a bot account
create_bot.RdCreate a new bot account on the Mattermost server. The bot will be owned by the authenticated user.
Usage
create_bot(
username,
display_name = NULL,
description = NULL,
verbose = FALSE,
auth = get_default_auth()
)Arguments
- username
Character. Required. The username for the bot. Must be unique across all users and bots on the server.
- display_name
Character. Optional display name for the bot.
- description
Character. Optional description of the bot.
- verbose
Logical. Print detailed request information? Default `FALSE`.
- auth
A `mattermost_auth` object created by [authenticate_mattermost()]. Defaults to [get_default_auth()].