Get All Reactions on a Mattermost Post
get_reactions.RdRetrieves all reactions made by all users on a given post.
Arguments
- post_id
The ID of the post to get reactions for.
- verbose
(Logical) If
TRUE, detailed information about the request and response will be printed.- auth
The authentication object created by
authenticate_mattermost(). Must be a validmattermost_authobject.