Get data of a single team from its team_id
get_team.RdGet data of a single team from its team_id
Value
A named list with team fields returned by the Mattermost API (e.g. `id`, `display_name`, `name`, `type`).
Examples
if (FALSE) { # \dontrun{
teams <- get_all_teams()
teaminfo <- lapply(teams$id, get_team)
} # }