List slash commands for a team
list_commands.RdRetrieve all commands for a team. By default, returns both system commands and custom commands the user has access to.
Value
A data frame of commands with columns such as `id`, `token`, `team_id`, `trigger`, `method`, `url`, `display_name`, `description`, `creator_id`, etc.
Examples
if (FALSE) { # \dontrun{
cmds <- list_commands("team123")
nrow(cmds)
# Only custom commands
custom <- list_commands("team123", custom_only = TRUE)
} # }