Print a mattermost_auth object
print.mattermost_auth.RdDisplays the server URL and a masked version of the bearer token to avoid accidentally exposing credentials in console output or logs.
Usage
# S3 method for class 'mattermost_auth'
print(x, ...)